==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/AssigningPolarStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarStyleEventArgsDescription } from "./AssigningPolarStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningPolarStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningPolarStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningPolarStyleEventArgsDescriptionMetadata.a == null) {
                AssigningPolarStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningPolarStyleEventArgsDescriptionMetadata.c(AssigningPolarStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningPolarStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(AssigningPolarStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningPolarStyleEventArgsDescriptionMetadata.b(a);
            a.ad("AssigningPolarStyleEventArgs", () => new AssigningPolarStyleEventArgsDescription());
            a.ac("AssigningPolarStyleEventArgs", AssigningPolarStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningPolarStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarStyleEventArgsDescriptionMetadata, 'AssigningPolarStyleEventArgsDescriptionMetadata');
    AssigningPolarStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarStyleEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/AssigningPolarStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarStyleEventArgsDescription } from "./AssigningPolarStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningPolarStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningPolarStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningPolarStyleEventArgsDescriptionMetadata.a == null) {
                AssigningPolarStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningPolarStyleEventArgsDescriptionMetadata.c(AssigningPolarStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningPolarStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningPolarStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningPolarStyleEventArgsDescriptionMetadata.b(a);
            a.ae("AssigningPolarStyleEventArgs", () => new AssigningPolarStyleEventArgsDescription());
            a.ad("AssigningPolarStyleEventArgs", AssigningPolarStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningPolarStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarStyleEventArgsDescriptionMetadata, 'AssigningPolarStyleEventArgsDescriptionMetadata');
    AssigningPolarStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarStyleEventArgsDescriptionMetadata;
})();
